@@ -1,18 +1,24 @@
-from elixir import Entity, has_field, String
+from elixir import *
 
-class Thing(Entity):
-    has_field('name', String(40))
-    has_field('type', String(40))
-    
-    class Stuff(Entity):
-        has_field('ping', String(32))
-        has_field('pong', String(32))
-    
-    has_field('other', String(40))
+def setup():
+    global Thing
 
+    class Thing(Entity):
+        name = Field(String(40))
+        type = Field(String(40))
+
+        class Stuff(Entity):
+            ping = Field(String(32))
+            pong = Field(String(32))
+
+        other = Field(String(40))
+
+    setup_all()
 
 class TestNestedClass(object):
     def test_nestedclass(self):
+
+        print "GLOBALS", globals().keys()
         assert 'name' in Thing.table.columns.keys()
         assert 'type' in Thing.table.columns.keys()
         assert 'other' in Thing.table.columns.keys()
@@ -23,4 +29,4 @@ class TestNestedClass(object):
         assert 'type' not in Thing.Stuff.table.columns.keys()
         assert 'other' not in Thing.Stuff.table.columns.keys()
         assert 'ping' in Thing.Stuff.table.columns.keys()
-        assert 'pong' in Thing.Stuff.table.columns.keys()
\ No newline at end of file
+        assert 'pong' in Thing.Stuff.table.columns.keys()
