@@ -3,8 +3,8 @@ test options
 """
 
 from sqlalchemy import UniqueConstraint, create_engine, Column
-from sqlalchemy.orm import create_session
-from sqlalchemy.exceptions import SQLError, ConcurrentModificationError 
+from sqlalchemy.orm import scoped_session, sessionmaker
+from sqlalchemy.exceptions import SQLError, ConcurrentModificationError
 from elixir import *
 
 class TestOptions(object):
@@ -18,37 +18,37 @@ class TestOptions(object):
     def test_version_id_col(self):
         class Person(Entity):
             name = Field(String(30))
- 
+
             using_options(version_id_col=True)
- 
+
         setup_all()
         Person.table.create()
- 
+
         p1 = Person(name='Daniel')
-        session.flush()
+        session.commit()
         session.clear()
-        
+
         person = Person.query.first()
         person.name = 'Gaetan'
-        session.flush()
-        session.clear()
+        session.commit()
         assert person.row_version == 2
- 
+        session.clear()
+
         person = Person.query.first()
         person.name = 'Jonathan'
-        session.flush()
-        session.clear()
+        session.commit()
         assert person.row_version == 3
- 
+        session.clear()
+
         # check that a concurrent modification raises exception
         p1 = Person.query.first()
-        s2 = create_session()
+        s2 = sessionmaker()()
         p2 = s2.query(Person).first()
         p1.name = "Daniel"
         p2.name = "Gaetan"
-        s2.flush()
+        s2.commit()
         try:
-            session.flush()
+            session.commit()
             assert False
         except ConcurrentModificationError:
             pass
@@ -76,7 +76,7 @@ class TestOptions(object):
         setup_all()
 
         # Note that this test is bogus as you cannot just change a column this
-        # way since the mapper is already constructed at this point and will 
+        # way since the mapper is already constructed at this point and will
         # use the old column!!! This test is only meant as a way to check no
         # exception is raised.
         #TODO: provide a proper test (using autoloaded tables)
@@ -112,31 +112,9 @@ class TestSessionOptions(object):
     def teardown(self):
         cleanup_all()
 
-    def test_session_context(self):
-        from sqlalchemy.ext.sessioncontext import SessionContext
-
-        engine = create_engine('sqlite:///')
-        
-        ctx = SessionContext(lambda: create_session(bind=engine))
-        
-        class Person(Entity):
-            using_options(session=ctx)
-            firstname = Field(String(30))
-            surname = Field(String(30))
-
-        setup_all()
-        create_all(engine)
-
-        homer = Person(firstname="Homer", surname='Simpson')
-        bart = Person(firstname="Bart", surname='Simpson')
-        ctx.current.flush()
-        
-        assert Person.query.session is ctx.current
-        assert Person.query.filter_by(firstname='Homer').one() is homer
-
     def test_manual_session(self):
         engine = create_engine('sqlite:///')
-        
+
         class Person(Entity):
             using_options(session=None)
             firstname = Field(String(30))
@@ -145,65 +123,24 @@ class TestSessionOptions(object):
         setup_all()
         create_all(engine)
 
-        session = create_session(bind=engine)
+        Session = sessionmaker(bind=engine)
+        session = Session()
 
         homer = Person(firstname="Homer", surname='Simpson')
         bart = Person(firstname="Bart", surname='Simpson')
 
         session.save(homer)
         session.save(bart)
-        session.flush()
-       
+        session.commit()
+
         bart.delete()
-        session.flush()
+        session.commit()
 
         assert session.query(Person).filter_by(firstname='Homer').one() is homer
         assert session.query(Person).count() == 1
 
-    def test_activemapper_session(self):
-        try:
-            from sqlalchemy.orm import scoped_session, sessionmaker
-            #TODO: this test, as-is has no sense on SA 0.4 since activemapper 
-            # session uses scoped_session, but we need to provide a new 
-            # test for that.
-            return
-        except ImportError:
-            pass
-
-        try:
-            from sqlalchemy.ext import activemapper
-        except ImportError:
-            return
-            
-        engine = create_engine('sqlite:///')
-
-        store = activemapper.Objectstore(lambda: create_session(bind=engine))
-
-        class Person(Entity):
-            using_options(session=store)
-            firstname = Field(String(30))
-            surname = Field(String(30))
-
-        setup_all()
-        create_all(engine)
-
-        homer = Person(firstname="Homer", surname='Simpson')
-        bart = Person(firstname="Bart", surname='Simpson')
-
-        store.flush()
-
-        assert Person.query.session is store.context.current
-        assert Person.query.filter_by(firstname='Homer').one() is homer
-
     def test_scoped_session(self):
-        try:
-            from sqlalchemy.orm import scoped_session, sessionmaker
-        except ImportError:
-            print "Not on version 0.4 of sqlalchemy"
-            return
-            
         engine = create_engine('sqlite:///')
-
         Session = scoped_session(sessionmaker(bind=engine))
 
         class Person(Entity):
@@ -216,25 +153,18 @@ class TestSessionOptions(object):
 
         homer = Person(firstname="Homer", surname='Simpson')
         bart = Person(firstname="Bart", surname='Simpson')
-        Session.flush()
+        Session.commit()
 
         assert Person.query.session is Session()
         assert Person.query.filter_by(firstname='Homer').one() is homer
-        
-    def test_global_scoped_session(self):
-        try:
-            from sqlalchemy.orm import scoped_session, sessionmaker
-        except ImportError:
-            print "Not on version 0.4 of sqlalchemy"
-            return
 
+    def test_global_scoped_session(self):
         global __session__
-        
+
         engine = create_engine('sqlite:///')
-        
         session = scoped_session(sessionmaker(bind=engine))
         __session__ = session
-        
+
         class Person(Entity):
             firstname = Field(String(30))
             surname = Field(String(30))
@@ -244,13 +174,13 @@ class TestSessionOptions(object):
 
         homer = Person(firstname="Homer", surname='Simpson')
         bart = Person(firstname="Bart", surname='Simpson')
-        session.flush()
-        
+        session.commit()
+
         assert Person.query.session is session()
         assert Person.query.filter_by(firstname='Homer').one() is homer
 
         del __session__
-        
+
 class TestTableOptions(object):
     def setup(self):
         metadata.bind = 'sqlite:///'
@@ -259,7 +189,7 @@ class TestTableOptions(object):
         cleanup_all()
 
     def test_unique_constraint(self):
-        
+
         class Person(Entity):
             firstname = Field(String(30))
             surname = Field(String(30))
@@ -271,24 +201,24 @@ class TestTableOptions(object):
         homer = Person(firstname="Homer", surname='Simpson')
         bart = Person(firstname="Bart", surname='Simpson')
 
-        session.flush()
+        session.commit()
 
         homer2 = Person(firstname="Homer", surname='Simpson')
 
         raised = False
         try:
-            session.flush()
+            session.commit()
         except SQLError:
             raised = True
 
         assert raised
 
-    def test_unique_constraint_belongs_to(self):
+    def test_unique_constraint_many_to_one(self):
         class Author(Entity):
-            name = Field(String)
+            name = Field(String(50))
 
         class Book(Entity):
-            title = Field(String, required=True)
+            title = Field(String(200), required=True)
             author = ManyToOne("Author")
 
             using_table_options(UniqueConstraint("title", "author_id"))
@@ -299,18 +229,18 @@ class TestTableOptions(object):
         lotr = Book(title="The Lord of the Rings", author=tolkien)
         hobbit = Book(title="The Hobbit", author=tolkien)
 
-        session.flush()
+        session.commit()
 
         tolkien2 = Author(name="Tolkien")
         hobbit2 = Book(title="The Hobbit", author=tolkien2)
 
-        session.flush()
+        session.commit()
 
         hobbit3 = Book(title="The Hobbit", author=tolkien)
 
         raised = False
         try:
-            session.flush()
+            session.commit()
         except SQLError:
             raised = True
 
